'use strict';

var tslib_es6 = require('../../external/tslib/tslib.es6.js');
var common = require('@nestjs/common');
var constant = require('../../shared/constant/config/constant.js');
require('../../shared/enum/environment.enum.js');
var instanceName_enum = require('../../shared/enum/instance-name.enum.js');
require('../../shared/enum/service.enum.js');

exports.ParameterStoreConfigService = class ParameterStoreConfigService {
    parameters;
    constructor(parameters) {
        this.parameters = parameters;
    }
    /**
     * Retrieves the value of a parameter with the specified name.
     * @param {IConfigGetProperties | string} properties - The parameter name or context options.
     * @returns {null | string} - The value of the parameter if found, or null if not found.
     */
    get(properties) {
        if (typeof properties === "string") {
            const found = this.parameters.find((parameter) => parameter.Name == properties);
            if (!found?.Value) {
                return null;
            }
            return found.Value;
        }
        else {
            const { application = this.getApplication(), environment = this.getEnvironment(), path = [], service = "" } = properties;
            let instanceName = properties.instanceName ?? `${application}-${instanceName_enum.EInstanceName.REAPER_API}`;
            if (properties.instanceName === instanceName_enum.EInstanceName.REAPER_API || properties.instanceName === instanceName_enum.EInstanceName.REAPER_API_TEST) {
                instanceName = `${application}-${properties.instanceName}`;
            }
            const parameterPath = `/${application}/${environment}/${instanceName}/${service}/${path.join("/")}`;
            const found = this.parameters.find((parameter) => parameter.Name == parameterPath);
            if (!found?.Value) {
                return null;
            }
            return found.Value;
        }
    }
    /**
     * Gets the application name from environment variables.
     * @returns {string} The application name.
     */
    getApplication() {
        return process.env.APPLICATION ?? "";
    }
    /**
     * Gets the environment name from environment variables.
     * @returns {string} The environment name.
     */
    getEnvironment() {
        return process.env.ENVIRONMENT ?? "";
    }
};
exports.ParameterStoreConfigService = tslib_es6.__decorate([
    common.Injectable(),
    tslib_es6.__param(0, common.Inject(constant.PARAMETER_STORE_CONFIG_PARAMETERS)),
    tslib_es6.__metadata("design:paramtypes", [Array])
], exports.ParameterStoreConfigService);
//# sourceMappingURL=config.service.js.map
