import { __decorate } from '../../external/tslib/tslib.es6.js';
import { Global, Module } from '@nestjs/common';
import { PARAMETER_STORE_CONFIG_PARAMETERS, PARAMETER_STORE_CONFIG_PROPERTIES } from '../../shared/constant/config/constant.js';
import { ParameterStoreConfigParametersProvider } from '../../shared/provider/config/config-parameters.provider.js';
import { ParameterStoreConfigPropertiesProvider } from '../../shared/provider/config/properties.provider.js';
import { ParameterStoreConfigSSMProvider } from '../../shared/provider/config/ssm-client.provider.js';
import { ParameterStoreService } from '../aws/parameter-store/parameter-store.service.js';
import { ParameterStoreConfigService } from './config.service.js';

var ParameterStoreConfigModule_1;
let ParameterStoreConfigModule = ParameterStoreConfigModule_1 = class ParameterStoreConfigModule {
    /**
     * Registers the given options for dynamic module configuration.
     * @param {IParameterStoreConfigProperties} options - The configuration options.
     * @returns {DynamicModule} - The dynamic module configuration.
     */
    static register(options) {
        const propertiesProvider = ParameterStoreConfigPropertiesProvider(options);
        return {
            exports: [ParameterStoreConfigService, PARAMETER_STORE_CONFIG_PARAMETERS],
            module: ParameterStoreConfigModule_1,
            providers: [propertiesProvider, ParameterStoreConfigParametersProvider, ParameterStoreConfigSSMProvider, ParameterStoreConfigService, ParameterStoreService],
        };
    }
    /**
     * Registers an asynchronous module in the application.
     * @param {IParameterStoreConfigAsyncModuleProperties} properties - The properties for the async module.
     * @returns {DynamicModule} - The registered dynamic module.
     */
    static registerAsync(properties) {
        const providers = this.createAsyncProviders(properties);
        return {
            exports: [ParameterStoreConfigService, PARAMETER_STORE_CONFIG_PARAMETERS],
            imports: properties.imports ?? [],
            module: ParameterStoreConfigModule_1,
            providers,
        };
    }
    /**
     * Creates an async options provider for the given `properties` object.
     * @param {IParameterStoreConfigAsyncModuleProperties} properties - The properties object used to configure the async options provider.
     * @returns {Provider} - The created async options provider.
     * @private
     */
    static createAsyncOptionsProvider(properties) {
        if (properties.useFactory) {
            return {
                inject: properties.inject ?? [],
                provide: PARAMETER_STORE_CONFIG_PROPERTIES,
                useFactory: properties.useFactory,
            };
        }
        const inject = properties.useExisting ?? properties.useClass;
        return {
            inject: inject ? [inject] : [],
            provide: PARAMETER_STORE_CONFIG_PROPERTIES,
            useFactory: async (optionsFactory) => {
                return optionsFactory.createOptions();
            },
        };
    }
    /**
     * Creates an array of Providers for asynchronous module configuration using the given properties.
     * @param {IParameterStoreConfigAsyncModuleProperties} properties - The properties for configuring the module asynchronously.
     * @returns {Array<Provider>} An array of Providers for the module configuration.
     * @private
     */
    static createAsyncProviders(properties) {
        const optionsProvider = this.createAsyncOptionsProvider(properties);
        const requestProviders = [optionsProvider, ParameterStoreConfigParametersProvider, ParameterStoreConfigSSMProvider, ParameterStoreConfigService, ParameterStoreService];
        if (properties.useExisting || properties.useFactory || !properties.useClass) {
            return requestProviders;
        }
        return [
            ...requestProviders,
            {
                provide: properties.useClass,
                useClass: properties.useClass,
            },
        ];
    }
};
ParameterStoreConfigModule = ParameterStoreConfigModule_1 = __decorate([
    Global(),
    Module({})
], ParameterStoreConfigModule);

export { ParameterStoreConfigModule };
//# sourceMappingURL=config.module.js.map
