import { __decorate, __param, __metadata } from '../../external/tslib/tslib.es6.js';
import { Injectable, Inject } from '@nestjs/common';
import { PARAMETER_STORE_CONFIG_PARAMETERS } from '../../shared/constant/config/constant.js';
import '../../shared/enum/environment.enum.js';
import { EInstanceName } from '../../shared/enum/instance-name.enum.js';
import '../../shared/enum/service.enum.js';

let ParameterStoreConfigService = class ParameterStoreConfigService {
    parameters;
    constructor(parameters) {
        this.parameters = parameters;
    }
    /**
     * Retrieves the value of a parameter with the specified name.
     * @param {IConfigGetProperties | string} properties - The parameter name or context options.
     * @returns {null | string} - The value of the parameter if found, or null if not found.
     */
    get(properties) {
        if (typeof properties === "string") {
            const found = this.parameters.find((parameter) => parameter.Name == properties);
            if (!found?.Value) {
                return null;
            }
            return found.Value;
        }
        else {
            const { application = this.getApplication(), environment = this.getEnvironment(), path = [], service = "" } = properties;
            let instanceName = properties.instanceName ?? `${application}-${EInstanceName.REAPER_API}`;
            if (properties.instanceName === EInstanceName.REAPER_API || properties.instanceName === EInstanceName.REAPER_API_TEST) {
                instanceName = `${application}-${properties.instanceName}`;
            }
            const parameterPath = `/${application}/${environment}/${instanceName}/${service}/${path.join("/")}`;
            const found = this.parameters.find((parameter) => parameter.Name == parameterPath);
            if (!found?.Value) {
                return null;
            }
            return found.Value;
        }
    }
    /**
     * Gets the application name from environment variables.
     * @returns {string} The application name.
     */
    getApplication() {
        return process.env.APPLICATION ?? "";
    }
    /**
     * Gets the environment name from environment variables.
     * @returns {string} The environment name.
     */
    getEnvironment() {
        return process.env.ENVIRONMENT ?? "";
    }
};
ParameterStoreConfigService = __decorate([
    Injectable(),
    __param(0, Inject(PARAMETER_STORE_CONFIG_PARAMETERS)),
    __metadata("design:paramtypes", [Array])
], ParameterStoreConfigService);

export { ParameterStoreConfigService };
//# sourceMappingURL=config.service.js.map
