import { ParameterStoreService } from '../../../modules/aws/parameter-store/parameter-store.service.js';
import { PARAMETER_STORE_CONFIG_PARAMETERS, PARAMETER_STORE_CONFIG_PROPERTIES } from '../../constant/config/constant.js';

/**
 * Factory provider that fetches parameters from AWS Parameter Store.
 * Constructs the parameter path based on application and environment settings,
 * then retrieves all parameters under that path.
 */
const ParameterStoreConfigParametersProvider = {
    inject: [PARAMETER_STORE_CONFIG_PROPERTIES, ParameterStoreService],
    provide: PARAMETER_STORE_CONFIG_PARAMETERS,
    useFactory: async (properties, parameterStoreService) => {
        let path;
        if (properties.basePath) {
            path = properties.basePath;
        }
        else if (properties.application) {
            path = `/${properties.application}`;
            if (properties.environment) {
                path = `${path}/${properties.environment}`;
            }
        }
        else {
            path = "/";
        }
        return parameterStoreService.getParametersByPath(path, properties.shouldDecryptParameters ?? false, properties.shouldUseRecursiveLoading ?? false, properties.isVerbose ?? false);
    },
};

export { ParameterStoreConfigParametersProvider };
//# sourceMappingURL=config-parameters.provider.js.map
